@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-
-   Copyright 2009 - 2016 Glencoe Software, Inc. All rights reserved.
-   Use is subject to license terms supplied in LICENSE.txt
-
-"""
+#
+#
+#   Copyright 2009 - 2016 Glencoe Software, Inc. All rights reserved.
+#   Use is subject to license terms supplied in LICENSE.txt
+#
+#
 from __future__ import print_function
 
 from builtins import zip
@@ -229,21 +229,9 @@ class BaseClient(object):
         self._optSetProp(id, "Ice.Default.PreferSecure", "1")
         self._optSetProp(id, "Ice.Plugin.IceSSL", "IceSSL:createIceSSL")
 
-        prop = "IceSSL.Ciphers"
-        try:
-            if sys.platform == "darwin":
-                self._optSetProp(id, prop, "(AES_256) (DH_anon.*AES)")
-            elif ssl.OPENSSL_VERSION_INFO >= (1, 1):
-                self._optSetProp(id, prop, "HIGH:ADH:@SECLEVEL=0")
-            else:
-                self._optSetProp(id, prop, "HIGH:ADH")
-        except Exception:
-            # OPENSSL_VERSION_INFO not available for 2.6, fall back to default
-            self._optSetProp(id, prop, "HIGH:ADH")
-
         self._optSetProp(id, "IceSSL.VerifyDepthMax", "6")
         self._optSetProp(id, "IceSSL.VerifyPeer", "0")
-        self._optSetProp(id, "IceSSL.Protocols", "tls1")
+        self._optSetProp(id, "IceSSL.Protocols", "tls1_0,tls1_1,tls1_2")
 
         # Setting block size
         self._optSetProp(
@@ -639,8 +627,8 @@ class BaseClient(object):
             # Acquire router and get the proxy
             prx = None
             retries = 0
+            reason = None
             while retries < 3:
-                reason = None
                 if retries > 0:
                     self.__logger.warning(
                         "%s - createSession retry: %s" % (reason, retries))
