@@ -368,8 +368,6 @@ class FsControl(CmdControl):
                 help="provide more details for each (slow)")
 
     def _table(self, args):
-        """
-        """
         from omero.util.text import TableBuilder
         tb = TableBuilder("#")
         if args.style:
@@ -406,20 +404,22 @@ class FsControl(CmdControl):
         values.append(filesizeformat(rsp.pyramidSize))
 
     def images(self, args):
-        """List images, filtering for archives, etc.
+        """
+        List images, filtering for archives, etc.
 
-This command is useful for showing pre-FS (i.e. OMERO 4.4
-and before) images which have original data archived with
-them. It *may* be possible to convert these to OMERO 5
-filesets.
+        This command is useful for showing pre-FS (i.e. OMERO 4.4
+        and before) images which have original data archived with
+        them. It *may* be possible to convert these to OMERO 5
+        filesets.
 
-Examples:
-
-    omero fs images --archived       # List only OMERO4 images
-    omero fs images --order=newest   # Default
-    omero fs images --order=largest  # Most used space
-    omero fs images --limit=500      # Longer listings
-    omero fs images --extended       # More details
+        Examples:
+        ```
+        omero fs images --archived       # List only OMERO4 images
+        omero fs images --order=newest   # Default
+        omero fs images --order=largest  # Most used space
+        omero fs images --limit=500      # Longer listings
+        omero fs images --extended       # More details
+        ```
         """
 
         from omero.rtypes import unwrap
@@ -482,16 +482,17 @@ Examples:
 
     @admin_only(AdminPrivilegeWriteManagedRepo, AdminPrivilegeChown)
     def mkdir(self, args):
-        """Make a new directory (admin-only)
+        """
+        Make a new directory (admin-only)
 
-Creates a new empty directory in the managed repository.
-A new storage volume may then be mounted at that location
-and the import template (omero.fs.repo.path) adjusted to
-target it. Once created, the directory may be deleted from
-the underlying filesystem and replaced with a symbolic link.
-Directories that violate the root-owned prefix components of
-omero.fs.repo.path are all set to be owned by the root user.
-"""
+        Creates a new empty directory in the managed repository.
+        A new storage volume may then be mounted at that location
+        and the import template (omero.fs.repo.path) adjusted to
+        target it. Once created, the directory may be deleted from
+        the underlying filesystem and replaced with a symbolic link.
+        Directories that violate the root-owned prefix components of
+        ``omero.fs.repo.path`` are all set to be owned by the root user.
+        """
 
         if len(args.new_dir) < 2:
             raise ValueError("directory path too short", args.new_dir)
@@ -510,13 +511,14 @@ omero.fs.repo.path are all set to be owned by the root user.
     # @admin_only(AdminPrivilegeWriteOwned, AdminPrivilegeWriteManagedRepo,
     #             AdminPrivilegeDeleteOwned, AdminPrivilegeDeleteManagedRepo)
     def rename(self, args):
-        """Moves an existing fileset to a new location (admin-only)
+        """
+        Moves an existing fileset to a new location (admin-only)
 
-After the import template (omero.fs.repo.path) has been changed,
-it may be useful to rename an existing fileset to match the new
-template. By default the original files and import log are also
-moved.
-"""
+        After the import template (omero.fs.repo.path) has been changed,
+        it may be useful to rename an existing fileset to match the new
+        template. By default the original files and import log are also
+        moved.
+        """
 
         # See https://trello.com/c/J3LNquSH/ for more information.
         # When reenabling, also reenable testRenameAdminOnly.
@@ -596,21 +598,19 @@ moved.
                 self.ctx.out(cmd)
 
     def repos(self, args):
-        """List all repositories.
+        """
+        List all repositories.
 
-These repositories are where OMERO stores all binary data for your
-system. Most useful is likely the "ManagedRepository" where OMERO 5
-imports to.
-
-Examples:
-
-    omero fs repos            # Show all
-    omero fs repos --managed  # Show only the managed repo
-                                  # Or to print only the directory
-                                  # under Unix:
-
-    omero fs repos --managed --style=plain | cut -d, -f5
+        These repositories are where OMERO stores all binary data for your
+        system. Most useful is likely the ``ManagedRepository`` where OMERO 5
+        imports to.
 
+        Examples:
+        ```
+        omero fs repos            # Show all
+        omero fs repos --managed  # Show only the managed repo or print only the directory under Unix  # noqa
+        omero fs repos --managed --style=plain | cut -d, -f5
+        ```
         """
 
         from omero.grid import ManagedRepositoryPrx as MRepo
@@ -643,19 +643,22 @@ Examples:
         self.ctx.out(str(tb.build()))
 
     def sets(self, args):
-        """List filesets by various criteria
+        """
+        List filesets by various criteria
 
-Filesets are bundles of original data imported into OMERO 5 and above
-which represent 1 *or more* images.
+        Filesets are bundles of original data imported into OMERO 5 and above
+        which represent 1 *or more* images.
 
-Examples:
+        Examples:
 
-    omero fs sets --order=newest        # Default
-    omero fs sets --order=oldest
-    omero fs sets --order=largest
-    omero fs sets --without-images      # Corrupt filesets
-    omero fs sets --with-transfer=ln_s  # Symlinked filesets
-    omero fs sets --check               # Proof the checksums
+        ```
+        omero fs sets --order=newest        # Default
+        omero fs sets --order=oldest
+        omero fs sets --order=largest
+        omero fs sets --without-images      # Corrupt filesets
+        omero fs sets --with-transfer=ln_s  # Symlinked filesets
+        omero fs sets --check               # Proof the checksums
+        ```
         """
 
         from omero.constants.namespaces import NSFILETRANSFER
@@ -778,7 +781,9 @@ Examples:
         self.ctx.out(str(tb.build()))
 
     def ls(self, args):
-        """List all the original files contained in a fileset"""
+        """
+        List all the original files contained in a fileset
+        """
         client = self.ctx.conn(args)
         gateway = BlitzGateway(client_obj=client)
         gateway.SERVICE_OPTS.setOmeroGroup("-1")
@@ -789,7 +794,9 @@ Examples:
             print(ofile.path + ofile.name)
 
     def logfile(self, args):
-        """Return the logfile associated with a fileset"""
+        """
+        Return the logfile associated with a fileset
+        """
         client = self.ctx.conn(args)
         query = client.sf.getQueryService()
         log = get_logfile(query, args.fileset.id.val)
@@ -834,32 +841,35 @@ Examples:
                 return pair
 
     def usage(self, args):
-        """Shows the disk usage for various objects.
+        """
+        Shows the disk usage for various objects.
 
-This command shows the total disk usage of various objects including:
-ExperimenterGroup, Experimenter, Project, Dataset, Folder, Screen, Plate,
-Well, WellSample, Image, Pixels, Annotation, Job, Fileset, OriginalFile.
-The total size returned will comprise the disk usage by all related files. Thus
-an image's size would typically include the files uploaded to a fileset,
-import log (Job), thumbnails, and, possibly, associated pixels or original
-files. These details can be displayed using the --report option.
+        This command shows the total disk usage of various objects including:
+        ExperimenterGroup, Experimenter, Project, Dataset, Folder, Screen, Plate,
+        Well, WellSample, Image, Pixels, Annotation, Job, Fileset, OriginalFile.
+        The total size returned will comprise the disk usage by all related files. Thus
+        an image's size would typically include the files uploaded to a fileset,
+        import log (Job), thumbnails, and, possibly, associated pixels or original
+        files. These details can be displayed using the --report option.
 
-Examples:
+        Examples:
 
-    omero fs usage             # total usage for current user
-    omero fs usage --report    # more detailed usage for current user
-    omero fs usage --groups    # total usage for current user's groups
-    # total usage for five images with minimal output
-    omero fs usage Image:1,2,3,4,5 --size_only
-    # total usage for all images with in a human readable format
-    omero fs usage Image:* --human-readable
-    # total usage for all users broken down by user and group
-    omero fs usage Experimenter:* --report --sum-by user group
-    # total usage for two projects and one dataset Megabytes
-    omero fs usage Project:1,2 Dataset:5 --units M
-    # in this last case if the dataset was within project 1 or 2
-    # then the size returned would be identical to:
-    omero fs usage Project:1,2 --units M
+        ```
+        omero fs usage             # total usage for current user
+        omero fs usage --report    # more detailed usage for current user
+        omero fs usage --groups    # total usage for current user's groups
+        # total usage for five images with minimal output
+        omero fs usage Image:1,2,3,4,5 --size_only
+        # total usage for all images with in a human readable format
+        omero fs usage Image:* --human-readable
+        # total usage for all users broken down by user and group
+        omero fs usage Experimenter:* --report --sum-by user group
+        # total usage for two projects and one dataset Megabytes
+        omero fs usage Project:1,2 Dataset:5 --units M
+        # in this last case if the dataset was within project 1 or 2
+        # then the size returned would be identical to:
+        omero fs usage Project:1,2 --units M
+        ```
         """
         from omero.cmd import DiskUsage2
 
@@ -1422,7 +1432,9 @@ class ImportTime(object):
                   .format(time, count, plural, old_div(time,count)))
 
     def print_summary(self):
-        """Report import metrics from map annotations on filesets"""
+        """
+        Report import metrics from map annotations on filesets
+        """
         from omero.sys import ParametersI
 
         hql = (
@@ -1459,7 +1471,9 @@ class ImportTime(object):
         self.print_summary_line()
 
     def print_summary_line(self):
-        """Report import metrics from the map annotations on a fileset"""
+        """
+        Report import metrics from the map annotations on a fileset
+        """
         if not self.metrics:
             return
         values = [str(self.fileset_id)]
