@@ -1,15 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-::
-    /*
-     *   $Id$
-     *
-     *   Copyright 2008 Glencoe Software, Inc. All rights reserved.
-     *   Use is subject to license terms supplied in LICENSE.txt
-     *
-     */
-"""
+#
+#
+#   Copyright 2008 Glencoe Software, Inc. All rights reserved.
+#   Use is subject to license terms supplied in LICENSE.txt
+#
 
 """
 Module which is responsible for creating rtypes from static
@@ -1238,7 +1233,10 @@ class RMapI(omero.RMap):
 class ObjectFactory(Ice.ObjectFactory):
 
     def __init__(self, cls, f):
-        self.id = cls.ice_staticId()
+        try:
+            self.id = cls.ice_staticId()
+        except Exception:
+            pass
         self.f = f
 
     def create(self, string):
